//-------------------------------------------------------------------//

// Synopsis:	Chow matrix - a singular Toeplitz lower Hessenberg matrix.

// Syntax: A = chow ( N , ALPHA , DELTA )

// Description:

//	A is a Toeplitz lower Hessenberg matrix.
//      A = H(ALPHA) + DELTA*EYE, where H(i,j) = ALPHA^(i-j+1).
//      H(ALPHA) has p = FLOOR((N+1)/2) zero eigenvalues, the rest
//	being 4*ALPHA*COS( k*PI/(N+2) )^2, k=1:N-p. 

//      Defaults: ALPHA = 1, DELTA = 0.

//        References:
//        T.S. Chow, A class of Hessenberg matrices with known
//           eigenvalues and inverses, SIAM Review, 11 (1969), pp. 391-395.
//        G. Fairweather, On the eigenvalues and eigenvectors of a class of
//           Hessenberg matrices, SIAM Review, 13 (1971), pp. 220-221.

//	This file is a translation of chow.m from version 2.0 of
//	"The Test Matrix Toolbox for Matlab", described in Numerical
//	Analysis Report No. 237, December 1993, by N. J. Higham.

// Dependencies
   require toeplitz

//-------------------------------------------------------------------//

chow = function ( n , alpha , delta )
{
  if (!exist (delta)) { delta = 0; }
  if (!exist (alpha)) { alpha = 1; }

  return toeplitz( alpha.^[1:n], [alpha, 1, zeros(1,n-2)] ) + delta*eye(n,n);
};
